@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef TERMINAL_APP_H
@@ -57,10 +57,12 @@ G_BEGIN_DECLS
 
 /* Configuration */
 
-#define CONF_PREFIX           "/apps/mate-terminal"
-#define CONF_GLOBAL_PREFIX    CONF_PREFIX "/global"
-#define CONF_PROFILES_PREFIX  CONF_PREFIX "/profiles"
-#define CONF_KEYS_PREFIX      CONF_PREFIX "/keybindings"
+#define CONF_PREFIX           "org.mate.terminal"
+#define CONF_GLOBAL_SCHEMA    CONF_PREFIX ".global"
+#define CONF_PROFILES_SCHEMA  CONF_PREFIX ".profiles"
+#define CONF_PROFILE_SCHEMA   CONF_PREFIX ".profile"
+#define CONF_KEYS_SCHEMA      CONF_PREFIX ".keybindings"
+#define CONF_PROFILE_PREFIX   "/org/mate/terminal/profiles/"
 
 #define MATE_TERMINAL_ICON_NAME "utilities-terminal"
 
